ns2: implement link sharing selector

Change-Id: I212fa1a65e8c16cf1e525d1962d5689446c7e49e
diff --git a/src/gb/gprs_ns2_internal.h b/src/gb/gprs_ns2_internal.h
index 6ea2fcc..de0f5d4 100644
--- a/src/gb/gprs_ns2_internal.h
+++ b/src/gb/gprs_ns2_internal.h
@@ -118,6 +118,9 @@
 	/*! llist head to hold all nsvc */
 	struct llist_head nsvc;
 
+	/*! count all active NSVCs with data capabilities */
+	int nsvc_data_count;
+
 	/*! true if this NSE was created by VTY or pcu socket) */
 	bool persistent;
 
@@ -154,7 +157,10 @@
 	/*! signalling weight. 0 = don't use for signalling (BVCI == 0)*/
 	uint8_t sig_weight;
 
-	/*! signaling weight. 0 = don't use for user data (BVCI != 0) */
+	/*! signalling packet counter for the load sharing function */
+	uint8_t sig_counter;
+
+	/*! data weight. 0 = don't use for user data (BVCI != 0) */
 	uint8_t data_weight;
 
 	/*! can be used by the bind/driver of the virtual circuit. e.g. ipv4/ipv6/frgre/e1 */